==> availity-angular-2.0.5.tgz: package/lib/ui/validation/field.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _module = require('../module');

var _module2 = _interopRequireDefault(_module);

var _utils = require('../../core/utils');

require('../../core/validation');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var AvValFieldController = function () {
  function AvValFieldController($element, avValAdapter, avVal, $log, $scope, $attrs) {
    _classCallCheck(this, AvValFieldController);

    this.av = { $element: $element, avValAdapter: avValAdapter, avVal: avVal, $log: $log, $scope: $scope, $attrs: $attrs };

    this.ngModel = null;
    this.rule = null;
    this.avValForm = null;
    this.avValInvalid = false;
    this.noEvent = {};
    this.placeholder = this.av.$element[0].placeholder;
  }

  _createClass(AvValFieldController, [{
    key: 'init',
    value: function init(options) {
      _extends(this, options);
      this.createId();
      this.setupValidators();
    }
  }, {
    key: 'createId',
    value: function createId() {
      this.ngModel.avId = (0, _utils.uuid)('avVal');
    }
  }, {
    key: 'isRadio',
    value: function isRadio() {
      return this.av.$element.is('input') && this.av.$attrs.type === 'radio';
    }
  }, {
    key: 'isCheckbox',
    value: function isCheckbox() {
      return this.av.$element.is('input') && this.av.$attrs.type === 'checkbox';
    }
  }, {
    key: 'updateElement',
    value: function updateElement() {

      this.av.avValAdapter.element({
        element: this.av.$element,
        ngModel: this.ngModel
      });

      this.av.avValAdapter.message({
        element: this.av.$element,
        ngModel: this.ngModel
      });
    }
  }, {
    key: 'setupValidators',
    value: function setupValidators() {

      var self = this;

      var schemaName = this.avValForm.rulesSchema;
      var ruleConfig = this.av.avVal.getRule(schemaName);

      if (!ruleConfig) {
        this.av.$log.error('Failed to get rules schema named [' + schemaName + '].  Forms must be tagged with a rules schema name for validation to work.');
        return;
      }

      var constraints = ruleConfig[this.ruleName];
      if (!constraints) {
        this.av.$log.info('Rule named [' + this.ruleName + '] could not be found in the current schema.');
        constraints = {};
      }

      Object.keys(constraints).forEach(function (constraintName) {

        var constraint = constraints[constraintName];
        if (!constraint) {

          // When extending rule sets, previous rules can be overridden with null so
          // delete the previous $validator
          delete self.ngModel.$validators[constraintName];
          return;
        }

        var validator = self.av.avVal.getService(constraintName);

        if (_angular2.default.isUndefined(validator)) {
          self.av.$log.warn('No validator defined for ' + constraintName);
          return;
        }

        self.ngModel.$validators[constraintName] = function contraintValidator(modelValue, viewValue) {

          var value = modelValue || viewValue;

          var valid = validator.validate({
            value: value,
            constraint: constraint,
            element: self.av.$element
          });

          return valid;
        };

        // Attach the constraint to the validator so that the message is available
        // to the validation container that is going to paint the message on screen.
        self.ngModel.$validators[constraintName].constraint = constraint;
      });
    }
  }, {
    key: 'reset',
    value: function reset() {
      this.ngModel.$setPristine();
      this.ngModel.$setUntouched();
      this.ngModel.$error = {};
      this.av.avValAdapter.reset(this.av.$element);
    }
  }, {
    key: 'onRunValidators',
    value: function onRunValidators() {
      if (this.ngModel.$dirty) {
        this.updateElement();
      }
    }
  }]);

  return AvValFieldController;
}();

_module2.default.controller('AvValFieldController', AvValFieldController);

_module2.default.directive('avValField', function ($log, avVal, avValAdapter, AV_VAL) {
  return {
    restrict: 'A',
    controller: 'AvValFieldController',
    require: ['^avValForm', 'ngModel', 'avValField', '?ngModelOptions', '?^ngModelOptions'],
    link: function link(scope, element, attrs, controllers) {

      var ruleName = attrs.avValField;

      var avValForm = controllers[0];
      var ngModel = controllers[1];
      var avValField = controllers[2];
      var ngModelOptions = controllers[3];
      var ngModelOptionsParent = controllers[4];

      if (!ngModelOptions || !ngModelOptionsParent) {

        ngModel.$options.createChild({
          '*': '$inherit',
          debounce: avValField.isCheckbox() || avValField.isRadio() ? AV_VAL.DEBOUNCE_QUICK : AV_VAL.DEBOUNCE
        });
      }

      // Wrap $$runValidators with our own function so we can intercept when the validation
      // pipeline finishes.
      var $$runValidators = ngModel.$$runValidators;
      var runValidators = function runValidators(modelValue, viewValue, doneCallback) {

        $$runValidators.call(ngModel, modelValue, viewValue, function (allValid) {
          doneCallback(allValid);
          avValField.onRunValidators();
        });
      };

      ngModel.$$runValidators = runValidators;

      if (!ngModel && !ruleName) {
        $log.error('avValField requires ngModel and a validation rule name to run.');
        return;
      }

      avValField.init({
        ngModel: ngModel,
        ruleName: ruleName,
        avValForm: avValForm
      });

      var reValidateOff = scope.$on(AV_VAL.EVENTS.REVALIDATE, function () {
        ngModel.$validate();
      });

      var submittedOff = scope.$on(AV_VAL.EVENTS.SUBMITTED, function () {
        ngModel.$dirty = true;
        ngModel.$validate();
      });

      // - Removes all errors on page,
      // - Does not reset view or model values.  This should to be handled by the application.
      var resetOff = scope.$on(AV_VAL.EVENTS.RESET, function () {
        avValField.reset();
      });

      scope.$on('$destroy', function () {
        reValidateOff();
        submittedOff();
        resetOff();
      });
    }
  };
});

==> availity-angular-3.0.0.tgz: package/lib/ui/validation/field.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _module = require('../module');

var _module2 = _interopRequireDefault(_module);

var _utils = require('../../core/utils');

require('../../core/validation');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var AvValFieldController = function () {
  function AvValFieldController($element, avValAdapter, avVal, $log, $scope, $attrs) {
    _classCallCheck(this, AvValFieldController);

    this.av = { $element: $element, avValAdapter: avValAdapter, avVal: avVal, $log: $log, $scope: $scope, $attrs: $attrs };

    this.ngModel = null;
    this.rule = null;
    this.avValForm = null;
    this.avValInvalid = false;
    this.noEvent = {};
    this.placeholder = this.av.$element[0].placeholder;
  }

  _createClass(AvValFieldController, [{
    key: 'init',
    value: function init(options) {
      _extends(this, options);
      this.createId();
      this.setupValidators();
    }
  }, {
    key: 'createId',
    value: function createId() {
      this.ngModel.avId = (0, _utils.uuid)('avVal');
    }
  }, {
    key: 'isRadio',
    value: function isRadio() {
      return this.av.$element.is('input') && this.av.$attrs.type === 'radio';
    }
  }, {
    key: 'isCheckbox',
    value: function isCheckbox() {
      return this.av.$element.is('input') && this.av.$attrs.type === 'checkbox';
    }
  }, {
    key: 'updateElement',
    value: function updateElement() {

      this.av.avValAdapter.element({
        element: this.av.$element,
        ngModel: this.ngModel
      });

      this.av.avValAdapter.message({
        element: this.av.$element,
        ngModel: this.ngModel
      });
    }
  }, {
    key: 'setupValidators',
    value: function setupValidators() {

      var self = this;

      var schemaName = this.avValForm.rulesSchema;
      var ruleConfig = this.av.avVal.getRule(schemaName);

      if (!ruleConfig) {
        this.av.$log.error('Failed to get rules schema named [' + schemaName + '].  Forms must be tagged with a rules schema name for validation to work.');
        return;
      }

      var constraints = ruleConfig[this.ruleName];
      if (!constraints) {
        this.av.$log.info('Rule named [' + this.ruleName + '] could not be found in the current schema.');
        constraints = {};
      }

      Object.keys(constraints).forEach(function (constraintName) {

        var constraint = constraints[constraintName];
        if (!constraint) {

          // When extending rule sets, previous rules can be overridden with null so
          // delete the previous $validator
          delete self.ngModel.$validators[constraintName];
          return;
        }

        var validator = self.av.avVal.getService(constraintName);

        if (_angular2.default.isUndefined(validator)) {
          self.av.$log.warn('No validator defined for ' + constraintName);
          return;
        }

        self.ngModel.$validators[constraintName] = function constraintValidator(modelValue, viewValue) {

          var value = modelValue || viewValue;

          var valid = validator.validate({
            value: value,
            constraint: constraint,
            element: self.av.$element
          });

          return valid;
        };

        // Attach the constraint to the validator so that the message is available
        // to the validation container that is going to paint the message on screen.
        self.ngModel.$validators[constraintName].constraint = constraint;
      });
    }
  }, {
    key: 'reset',
    value: function reset() {
      this.ngModel.$setPristine();
      this.ngModel.$setUntouched();
      this.ngModel.$error = {};
      this.av.avValAdapter.reset(this.av.$element);
    }
  }, {
    key: 'onRunValidators',
    value: function onRunValidators() {
      if (this.ngModel.$dirty) {
        this.updateElement();
      }
    }
  }]);

  return AvValFieldController;
}();

_module2.default.controller('AvValFieldController', AvValFieldController);

_module2.default.directive('avValField', function ($log, avVal, avValAdapter, AV_VAL) {
  return {
    restrict: 'A',
    controller: 'AvValFieldController',
    require: ['^avValForm', 'ngModel', 'avValField', '?ngModelOptions', '?^ngModelOptions'],
    link: function link(scope, element, attrs, controllers) {

      var ruleName = attrs.avValField;

      var avValForm = controllers[0];
      var ngModel = controllers[1];
      var avValField = controllers[2];
      var ngModelOptions = controllers[3];
      var ngModelOptionsParent = controllers[4];

      if (!ngModelOptions || !ngModelOptionsParent) {

        ngModel.$options.createChild({
          '*': '$inherit',
          debounce: avValField.isCheckbox() || avValField.isRadio() ? AV_VAL.DEBOUNCE_QUICK : AV_VAL.DEBOUNCE
        });
      }

      // Wrap $$runValidators with our own function so we can intercept when the validation
      // pipeline finishes.
      var $$runValidators = ngModel.$$runValidators;
      var runValidators = function runValidators(modelValue, viewValue, doneCallback) {

        $$runValidators.call(ngModel, modelValue, viewValue, function (allValid) {
          doneCallback(allValid);
          avValField.onRunValidators();
        });
      };

      ngModel.$$runValidators = runValidators;

      if (!ngModel && !ruleName) {
        $log.error('avValField requires ngModel and a validation rule name to run.');
        return;
      }

      avValField.init({
        ngModel: ngModel,
        ruleName: ruleName,
        avValForm: avValForm
      });

      var reValidateOff = scope.$on(AV_VAL.EVENTS.REVALIDATE, function () {
        ngModel.$validate();
      });

      var submittedOff = scope.$on(AV_VAL.EVENTS.SUBMITTED, function () {
        ngModel.$dirty = true;
        ngModel.$validate();
      });

      // - Removes all errors on page,
      // - Does not reset view or model values.  This should to be handled by the application.
      var resetOff = scope.$on(AV_VAL.EVENTS.RESET, function () {
        avValField.reset();
      });

      scope.$on('$destroy', function () {
        reValidateOff();
        submittedOff();
        resetOff();
      });
    }
  };
});
